summaryrefslogtreecommitdiff
path: root/src/mongo/db/exec/or.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/exec/or.h')
-rw-r--r--src/mongo/db/exec/or.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/exec/or.h b/src/mongo/db/exec/or.h
index 3aaa72e0de9..c0f92a01327 100644
--- a/src/mongo/db/exec/or.h
+++ b/src/mongo/db/exec/or.h
@@ -37,11 +37,11 @@
namespace mongo {
/**
* This stage outputs the union of its children. It optionally deduplicates on DiskLoc.
*
- * Preconditions: Valid DiskLoc.
+ * Preconditions: Valid RecordId.
*
* If we're deduping, we may fail to dedup any invalidated DiskLoc properly.
*/
class OrStage : public PlanStage {
public:
@@ -56,7 +56,7 @@ namespace mongo {
virtual void saveState();
virtual void restoreState(OperationContext* opCtx);
- virtual void invalidate(OperationContext* txn, const DiskLoc& dl, InvalidationType type);
+ virtual void invalidate(OperationContext* txn, const RecordId& dl, InvalidationType type);
virtual std::vector<PlanStage*> getChildren() const;
@@ -83,11 +83,11 @@ namespace mongo {
// Which of _children are we calling work(...) on now?
size_t _currentChild;
- // True if we dedup on DiskLoc, false otherwise.
+ // True if we dedup on RecordId, false otherwise.
bool _dedup;
- // Which DiskLocs have we returned?
- unordered_set<DiskLoc, DiskLoc::Hasher> _seen;
+ // Which RecordIds have we returned?
+ unordered_set<RecordId, RecordId::Hasher> _seen;
// Stats
CommonStats _commonStats;
@@ -37,11 +37,11 @@
namespace mongo {
/**
- * This stage outputs the union of its children. It optionally deduplicates on DiskLoc.
+ * This stage outputs the union of its children. It optionally deduplicates on RecordId.
*
@@ -37,11 +37,11 @@
*
- * If we're deduping, we may fail to dedup any invalidated DiskLoc properly.
+ * If we're deduping, we may fail to dedup any invalidated RecordId properly.
*/
class OrStage : public PlanStage {